﻿from django.db import models
from django.utils.safestring import mark_safe
from django.contrib.auth.models import User
import datetime

#Class model
class Class(models.Model):
    class_id = models.AutoField(null=True, blank=True, primary_key=True)
    name = models.CharField(max_length=20, verbose_name='Tên lớp')
    formTeacher = models.OneToOneField('Teacher', verbose_name='Giáo viên chủ nhiệm', null=True, blank=True)
    course = models.ForeignKey('Course', verbose_name='Khóa', related_name='classes')

    def __unicode__(self):
        return u'%s-%s' % (self.course, self.name)

    class Meta:
        ordering = ['course', 'name']
        verbose_name = 'Lớp'
        verbose_name_plural = 'Lớp'

# Course model	
class Course(models.Model):
    course_id = models.AutoField(null=True, blank=True, primary_key=True)
    startingYear = models.PositiveSmallIntegerField(default=2000, verbose_name='Khóa')

    def __unicode__(self):
        return u'%d' % self.startingYear

    class Meta:
        ordering = ['startingYear']
        verbose_name = 'Khóa học'
        verbose_name_plural = 'Khóa học'

# Lesson model
WEEK_DAY = (('mon','Monday'),('tue','Tuesday'),('wed','Wednesday'),
            ('thu','Thursday'),('fri','Friday'),('sat','Saturday'),
            ('sun','Sunday'))
TIET = (('t1','Tiet 1'),('t2','Tiet 2'),('t3','Tiet 3'),('t4','Tiet 4'),('t5','Tiet 5'),
        ('t6','Tiet 6'),('t7','Tiet 7'),('t8','Tiet 8'),('t9','Tiet 9'),('t10','Tiet 10'))

class Lesson(models.Model):
    lesson_id = models.AutoField(null=True, blank=True, primary_key=True)
    subject = models.ForeignKey('Subject', verbose_name='Môn học')
    theClass = models.ForeignKey('Class', verbose_name='Lớp học')
    teacher = models.ForeignKey('Teacher', verbose_name='Giáo viên')
    day = models.CharField(max_length=10, choices=WEEK_DAY, verbose_name='Thứ')
    tiet = models.CharField(max_length=8, choices=TIET, verbose_name='Tiết')

    def __unicode__(self):
        return u'%s' %self.subject
    class Meta:
        verbose_name = 'Tiết học'
        verbose_name_plural = 'Tiết học'

# Student model
class Student(User):
    student_id = models.AutoField(null=True, blank=True, primary_key=True)
    birthday = models.DateField(verbose_name='Ngày sinh')
    studyingClass = models.ForeignKey('Class', verbose_name='Lớp', null=True, blank=True)

    def save(self, *args, **kwargs):
        self.is_student = True
        super(Student, self).save(*args, **kwargs)
        
    def __unicode__(self):
        return u'%s %s' % (self.last_name, self.first_name)

    class Meta:
        ordering = ['studyingClass', 'first_name', 'last_name']
        verbose_name = 'Học sinh'
        verbose_name_plural = 'Học sinh'
		
# Manager model
class Manager(User):
    manager_id = models.AutoField(null=True, blank=True, primary_key=True)

    def save(self, *args, **kwargs):
        self.is_manager = True
        super(Manager, self).save(*args, **kwargs)
    
    def __unicode__(self):
        return u'%s %s' %(self.first_name, self.last_name)

    class Meta:
        ordering = ['manager_id']
        verbose_name = 'Người quản lý'
        verbose_name_plural = 'Người quản lý'
        

# Parent model
class Parent(User):
    parent_id = models.AutoField(null=True, blank=True, primary_key=True)
    phoneNumber = models.CharField(max_length=20, blank=True, verbose_name='Số điện thoại')
    address = models.CharField(max_length=50, blank=True, verbose_name='Địa chỉ')

    def save(self, *args, **kwargs):
        self.is_parent = True
        super(Parent, self).save(*args, **kwargs)

    def __unicode__(self):
        return u'%s %s' % (self.first_name, self.last_name)

    class Meta:
        ordering = ['parent_id']
        verbose_name = 'Phụ huynh'
        verbose_name_plural = 'Phụ huynh'
		
# Teacher model
class Teacher(User):
    teacher_id = models.AutoField(null=True, blank=True, primary_key=True)
    phoneNumber = models.CharField(max_length=20, blank=True, verbose_name='Số điện thoại')
    address = models.CharField(max_length=50, blank=True, verbose_name='Địa chỉ')
    proSubject = models.ForeignKey('Subject', verbose_name='Môn dạy')

    def save(self, *args, **kwargs):
        self.is_teacher = True
        super(Teacher, self).save(*args, **kwargs)
        
    def __unicode__(self):
        return u'%s %s' %(self.last_name, self.first_name)

    class Meta:
        ordering = ['proSubject', 'first_name', 'last_name']
        verbose_name = 'Giáo viên'
        verbose_name_plural = 'Giáo viên'
        
	
# Subject model	
class Subject(models.Model):
    subject_id = models.AutoField(null=True, blank=True, primary_key=True)
    name = models.CharField(max_length=30, verbose_name='Tên môn học')

    def __unicode__(self):
        return u'%s' % self.name

    class Meta:
        ordering = ['name']
        verbose_name = 'Môn học'
        verbose_name_plural = 'Môn học'
    
		
# Other models
class SubjectOfStudent(models.Model):
    theStudent = models.ForeignKey('Student')
    theSubject = models.ForeignKey('Subject')
    
    def __unicode__(self):
        return u'%s_%s' % (self.theStudent, self.theSubject)
    class Meta:
        unique_together = ('theStudent', 'theSubject')
        verbose_name = 'Môn học của học sinh'
        verbose_name_plural = 'Môn học của học sinh'

class SubjectOfTeacher(models.Model):
    theTeacher = models.ForeignKey('Teacher')
    theSubject = models.ForeignKey('Subject')
    
    def __unicode__(self):
        return u'%s_%s' % (self.theTeacher, self.theSubject)
    class Meta:
        unique_together = ('theTeacher', 'theSubject')
        verbose_name = 'Chuyên môn của giáo viên'
        verbose_name_plural = 'Chuyên môn của giáo viên'

class TeacherClassLesson(models.Model):
    theTeacher = models.ForeignKey('Teacher')
    theClass = models.ForeignKey('Class')
    theLesson = models.ForeignKey('Subject')

    def __unicode__(self):
        return u'%s_%s_%s' % (self.theTeacher,self.theClass,self.theLesson)
    class Meta:
        verbose_name = 'Phân công tiết học'
        verbose_name_plural = 'Phân công tiết học'


GRADE_TYPE = (('m','Mieng'),('15p','15 phut'),('45p','45 phut'),('gk','Giua ki'),('ck','Cuoi ky'))
class GradeOfStudent(models.Model):
    theStudent = models.ForeignKey('Student')
    theSubject = models.ForeignKey('Subject')
    gradeType = models.CharField(max_length=8, choices=GRADE_TYPE)
    grade = models.PositiveSmallIntegerField(default=0)

    def __unicode__(self):
        return u'%s_%s_%s_%d' % (self.theStudent, self.theSubject, self.gradeType, self.grade)
    class Meta:
        verbose_name = 'Kết quả'
        verbose_name_plural = 'Kết quả'
    
    
    
